@@ -37,7 +37,7 @@ namespace pika::cuda::experimental {
         template <typename Receiver, typename F>
         struct then_on_host_receiver_impl<Receiver, F>::then_on_host_receiver_type
         {
-            using is_receiver = void;
+            PIKA_STDEXEC_RECEIVER_CONCEPT
 
             PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
             PIKA_NO_UNIQUE_ADDRESS std::decay_t<F> f;
@@ -127,7 +127,7 @@ namespace pika::cuda::experimental {
         template <typename Sender, typename F>
         struct then_on_host_sender_impl<Sender, F>::then_on_host_sender_type
         {
-            using is_sender = void;
+            PIKA_STDEXEC_SENDER_CONCEPT
 
             std::decay_t<Sender> sender;
             std::decay_t<F> f;
