@@ -42,14 +42,10 @@ namespace pika::mpi::experimental {
             PIKA_CONCEPT_REQUIRES_(
                 pika::execution::experimental::is_sender_v<std::decay_t<Sender>>)>
         friend PIKA_FORCEINLINE pika::execution::experimental::unique_any_sender<>
-        tag_fallback_invoke(
-            transform_mpi_t, Sender&& sender, F&& f, stream_type s = stream_type::automatic)
+        tag_fallback_invoke(transform_mpi_t, Sender&& sender, F&& f)
         {
             using namespace pika::mpi::experimental::detail;
-            using namespace pika::debug::detail;
-            PIKA_DETAIL_DP(mpi_tran<5>,
-                debug(str<>("transform_mpi_t"), "tag_fallback_invoke", "stream",
-                    detail::stream_name(s)));
+            PIKA_DETAIL_DP(mpi_tran<5>, debug(str<>("transform_mpi_t"), "tag_fallback_invoke"));
 
             using execution::thread_priority;
             using pika::execution::experimental::just;
@@ -79,14 +75,14 @@ namespace pika::mpi::experimental {
             PIKA_ASSERT(pool_exists() == need_pool);
 #endif
 
-            using execution::thread_priority;
-            thread_priority p =
-                use_HP_completion(mode) ? thread_priority::high : thread_priority::normal;
-            if (inline_req)
+            execution::thread_priority p = use_priority_boost(mode) ?
+                execution::thread_priority::boost :
+                execution::thread_priority::normal;
+            if (inline_req || !pool_exists())
             {
-                return dispatch_mpi_sender<Sender, F>{PIKA_MOVE(sender), PIKA_FORWARD(F, f), s} |
+                return dispatch_mpi_sender<Sender, F>{PIKA_MOVE(sender), PIKA_FORWARD(F, f)} |
                     let_value([=](MPI_Request request) -> unique_any_sender<> {
-                        if (inline_com)
+                        if (inline_com || !pool_exists())
                         {
                             if (request == MPI_REQUEST_NULL)
                                 return just();
@@ -94,7 +90,7 @@ namespace pika::mpi::experimental {
                                 return just(request) | trigger_mpi(mode);
                         }
                         else
-                        {
+                        {    // do not transfer if there is no pool
                             if (request == MPI_REQUEST_NULL)
                                 return transfer_just(default_pool_scheduler(p));
                             else
@@ -105,9 +101,8 @@ namespace pika::mpi::experimental {
             }
             else
             {
-                auto snd0 = PIKA_FORWARD(Sender, sender) | transfer(mpi_pool_scheduler());
-                return dispatch_mpi_sender<decltype(snd0), F>{
-                           PIKA_MOVE(snd0), PIKA_FORWARD(F, f), s} |
+                auto snd0 = PIKA_FORWARD(Sender, sender) | transfer(mpi_pool_scheduler(p));
+                return dispatch_mpi_sender<decltype(snd0), F>{PIKA_MOVE(snd0), PIKA_FORWARD(F, f)} |
                     let_value([=](MPI_Request request) -> unique_any_sender<> {
                         if (inline_com)
                         {
@@ -132,11 +127,10 @@ namespace pika::mpi::experimental {
         // tag invoke overload for mpi_transform
         //
         template <typename F>
-        friend constexpr PIKA_FORCEINLINE auto
-        tag_fallback_invoke(transform_mpi_t, F&& f, stream_type s = stream_type::automatic)
+        friend constexpr PIKA_FORCEINLINE auto tag_fallback_invoke(transform_mpi_t, F&& f)
         {
-            return pika::execution::experimental::detail::partial_algorithm<transform_mpi_t, F,
-                stream_type>{PIKA_FORWARD(F, f), /*p, */ s};
+            return pika::execution::experimental::detail::partial_algorithm<transform_mpi_t, F>{
+                PIKA_FORWARD(F, f)};
         }
 
     } transform_mpi{};
