@@ -235,7 +235,7 @@ namespace PIKA_DETAIL_NS_DEBUG {
     // ------------------------------------------------------------------
     // helper class for printing time since start
     // ------------------------------------------------------------------
-    char const* hostname_print_helper::get_hostname() const
+    char const* hostname_print_helper::get_hostname_and_rank() const
     {
         static bool initialized = false;
         static char hostname_[20] = {'\0'};
@@ -252,6 +252,20 @@ namespace PIKA_DETAIL_NS_DEBUG {
         return hostname_;
     }
 
+    char const* hostname_print_helper::get_hostname() const
+    {
+        static bool initialized = false;
+        static char hostname_[20] = {'\0'};
+        if (!initialized)
+        {
+            initialized = true;
+#if !defined(__FreeBSD__)
+            gethostname(hostname_, std::size_t(12));
+#endif
+        }
+        return hostname_;
+    }
+
     int hostname_print_helper::guess_rank() const
     {
 #if defined(__FreeBSD__)
@@ -278,7 +292,7 @@ namespace PIKA_DETAIL_NS_DEBUG {
 
     std::ostream& operator<<(std::ostream& os, hostname_print_helper const& h)
     {
-        os << str<13>(h.get_hostname()) << " ";
+        os << str<13>(h.get_hostname_and_rank()) << " ";
         return os;
     }
 
