@@ -56,6 +56,8 @@ void test_execute()
 
 struct check_context_receiver
 {
+    PIKA_STDEXEC_RECEIVER_CONCEPT
+
     pika::thread::id parent_id;
     pika::mutex& mtx;
     pika::condition_variable& cond;
@@ -216,6 +218,8 @@ void test_sender_receiver_then_arguments()
 template <typename F>
 struct callback_receiver
 {
+    PIKA_STDEXEC_RECEIVER_CONCEPT
+
     std::decay_t<F> f;
     pika::mutex& mtx;
     pika::condition_variable& cond;
@@ -1355,9 +1359,9 @@ void test_completion_scheduler()
     }
 
     {
-        auto sender =
-            ex::bulk(ex::then(ex::transfer_just(ex::thread_pool_scheduler{}, 42), [](int) {}), 10,
-                [](int, int) {});
+        auto sender = ex::bulk(
+            ex::then(ex::transfer_just(ex::thread_pool_scheduler{}, 42), [](int x) { return x; }),
+            10, [](int, int) {});
         auto completion_scheduler =
             ex::get_completion_scheduler<ex::set_value_t>(ex::get_env(sender));
         static_assert(
