@@ -103,6 +103,7 @@ namespace pika::functional::detail {
 
 # include <pika/config.hpp>
 # include <pika/functional/tag_invoke.hpp>
+# include <pika/type_support/type_identity.hpp>
 
 # include <type_traits>
 # include <utility>
@@ -196,11 +197,12 @@ namespace pika::functional::detail {
         is_nothrow_tag_fallback_invocable<Tag, Args...>::value;
 
     template <typename Tag, typename... Args>
-    using tag_fallback_invoke_result =
-        std::invoke_result<decltype(tag_fallback_invoke_ns::tag_fallback_invoke), Tag, Args...>;
+    using tag_fallback_invoke_result_t = decltype(tag_fallback_invoke_ns::tag_fallback_invoke(
+        std::declval<Tag>(), std::declval<Args>()...));
 
     template <typename Tag, typename... Args>
-    using tag_fallback_invoke_result_t = typename tag_fallback_invoke_result<Tag, Args...>::type;
+    using tag_fallback_invoke_result =
+        pika::detail::type_identity<tag_fallback_invoke_result_t<Tag, Args...>>;
 
     ///////////////////////////////////////////////////////////////////////////////
     namespace tag_base_ns {
